Module: DuckTyper

Defined in:
lib/duck_typer.rb,
lib/duck_typer/rspec.rb,
lib/duck_typer/version.rb,
lib/duck_typer/minitest.rb,
lib/duck_typer/interface_setup.rb,
lib/duck_typer/method_inspector.rb,
lib/duck_typer/interface_checker.rb,
lib/duck_typer/params_normalizer.rb,
lib/duck_typer/result_formatting.rb,
lib/duck_typer/bulk_interface_checker.rb,
lib/duck_typer/interface_checker/result.rb,
lib/duck_typer/canonical_interface_checker.rb,
lib/duck_typer/canonical_interface_checker/result.rb

Overview

DuckTyper enforces duck-typed interfaces in Ruby by comparing the public method signatures of classes, surfacing mismatches through your test suite.

Defined Under Namespace

Modules: MethodInspector, Minitest, ParamsNormalizer, RSpec, ResultFormatting Classes: BulkInterfaceChecker, CanonicalInterfaceChecker, InterfaceChecker, InterfaceSetup, MethodNotFoundError, PrivateMethodError, TooManyParametersError

Constant Summary collapse

VERSION =
"0.6.0"